==> flutter_widget_from_html_core-0.4.0-rc.2020040701.tar.gz: lib/src/ops/tag_a.dart <==
part of '../core_widget_factory.dart';

class _TagA {
  final WidgetFactory wf;

  _TagA(this.wf);

  BuildOp get buildOp => BuildOp(
        defaultStyles: (meta, __) {
          final styles = [_kCssTextDecoration, _kCssTextDecorationUnderline];

          if (wf.hyperlinkColor != null) {
            styles.addAll([
              _kCssColor,
              _convertColorToHex(wf.hyperlinkColor),
            ]);
          }

          return styles;
        },
        onPieces: (meta, pieces) {
          final onTap = _buildGestureTapCallback(meta);
          if (onTap == null) return pieces;

          final recognizer =
              TapGestureRecognizer(debugOwner: meta.domElement.outerHtml)
                ..onTap = onTap;

          return pieces.map(
            (piece) => piece.hasWidgets
                ? BuiltPiece.widgets(WidgetPlaceholder.wrap(
                    piece.widgets, wf.buildGestureDetectors, wf, onTap))
                : _buildBlock(meta, piece, onTap, recognizer),
          );
        },
      );

  BuiltPiece _buildBlock(
    NodeMetadata meta,
    BuiltPiece piece,
    GestureTapCallback onTap,
    GestureRecognizer recognizer,
  ) =>
      piece
        ..text.bits.forEach((bit) => bit is TextWidget
            ? bit.widget?.wrapWith(wf.buildGestureDetectors, onTap)
            : bit.tsb?.recognizer = recognizer);

  GestureTapCallback _buildGestureTapCallback(NodeMetadata meta) {
    final attrs = meta.domElement.attributes;
    final href = attrs.containsKey('href') ? attrs['href'] : null;
    final url = wf.constructFullUrl(href);
    return wf.buildGestureTapCallbackForUrl(url);
  }
}

==> flutter_widget_from_html_core-0.4.3.tar.gz: lib/src/ops/tag_a.dart <==
part of '../core_widget_factory.dart';

class _TagA {
  final WidgetFactory wf;

  _TagA(this.wf);

  BuildOp get buildOp => BuildOp(
        defaultStyles: (meta, __) {
          final styles = [_kCssTextDecoration, _kCssTextDecorationUnderline];

          final color = wf.widget?.hyperlinkColor;
          if (color != null) {
            styles.addAll([_kCssColor, _convertColorToHex(color)]);
          }

          return styles;
        },
        onPieces: (meta, pieces) {
          final onTap = _buildGestureTapCallback(meta);
          if (onTap == null) return pieces;

          return pieces.map(
            (piece) => piece.hasWidgets
                ? BuiltPiece.widgets(WidgetPlaceholder.wrap(
                    piece.widgets, wf.buildGestureDetectors, wf, onTap))
                : _buildBlock(meta, piece, onTap),
          );
        },
      );

  BuiltPiece _buildBlock(
    NodeMetadata meta,
    BuiltPiece piece,
    GestureTapCallback onTap,
  ) =>
      piece
        ..text.bits.toList(growable: false).forEach((bit) => bit is TextWidget
            ? bit.widget?.wrapWith(wf.buildGestureDetectors, onTap)
            : bit is TextData
                ? bit.replaceWith(_TagATextData(bit, onTap, wf))
                : null);

  GestureTapCallback _buildGestureTapCallback(NodeMetadata meta) {
    final attrs = meta.domElement.attributes;
    final href = attrs.containsKey('href') ? attrs['href'] : null;
    final url = wf.constructFullUrl(href);
    return wf.buildGestureTapCallbackForUrl(url);
  }
}

class _TagATextData extends TextData {
  final TextData bit;
  final GestureTapCallback onTap;
  final WidgetFactory wf;

  _TagATextData(this.bit, this.onTap, this.wf)
      : super(bit.parent, bit.data, bit.tsb);

  @override
  bool get canCompile => true;

  @override
  InlineSpan compile(TextStyle style) =>
      wf.buildGestureTapCallbackSpan(bit.data, onTap, style);
}
